#!/bin/bash

FUNCTIONS="./functions.sh"
. $FUNCTIONS

pip install pyserial git+https://github.com/reingart/pyfiscalprinter.git

# Compatibilidad hacia atrás. No deberia hacer falta con fierro > 1.36.3
FISCAL_DRIVER_MODULE=$(python -O -c "from pyfiscalprinter import epsonFiscalDriver; print epsonFiscalDriver.__file__")
ln -sf "$FISCAL_DRIVER_MODULE" /usr/local/lib/python2.7/dist-packages/

if [ -z "$TK_FISCAL_TYPE" ]; then
    echo "No se instala servicio de epsonFiscalDriver porque no está definido el tipo de fiscal"
    exit 0
fi

if [ -z "$TK_FISCAL_DEVICE" ]; then
    for candidate in /dev/ttyUSB? /dev/ttyACM? /dev/ttyS?; do
        if [ -c "$candidate" ]; then
            TK_FISCAL_DEVICE="$candidate"
            break
        fi
    done
fi

if is_systemd; then
    cat <<EOF > /etc/systemd/system/epsonFiscalDriver.service
[Unit]
Description=Driver de impresora fiscal Epson/Hasar

[Service]
Type=simple
ExecStart=/usr/bin/env python2 -m pyfiscalprinter.epsonFiscalDriver -d $TK_FISCAL_DEVICE -t $TK_FISCAL_TYPE -p $TK_FISCAL_PORT
Restart=no

[Install]
WantedBy=multi-user.target
EOF
    systemctl enable epsonFiscalDriver
else
    cat <<EOF > /etc/init/epsonFiscalDriver.conf
description "Driver de impresora fiscal Epson/Hasar"

start on runlevel [2345]
stop on shutdown

exec /usr/bin/env python2 -m pyfiscalprinter.epsonFiscalDriver -d $TK_FISCAL_DEVICE -t $TK_FISCAL_TYPE -p $TK_FISCAL_PORT
EOF
fi

restart_service epsonFiscalDriver

