#!/usr/bin/env python

import sys

import unittest
import argparse

import conf


def run_tests():
    suite = unittest.defaultTestLoader.discover('tests')
    runner = unittest.TextTestRunner(verbosity=3, failfast=True)
    result = runner.run(suite)

    return result.wasSuccessful()


if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='Ejecutar tests de instalacion de fierro')

    parser.add_argument('-t', '--test', action='append',
                        help="Componentes a testear. Ejemplo: offline, fierroserver, fierroclient.")
    parser.add_argument('-c', '--client-instance', action='append', default=[],
                        help="Testear instancias adicionales de fierroclient. Ejemplo: -c=-colihue")
    parser.add_argument('-f', '--server-instance', action='append', default=[],
                        help="Testear instancias adicionales de fierroserver. Ejemplo: -f=-colihue")

    args = vars(parser.parse_args())

    conf.TEST_COMPONENTS = ['fierroclient'] if not args['test'] else args['test']
    conf.FIERROCLIENT_INSTANCES.extend(args['client_instance'])
    conf.FIERROSERVER_INSTANCES.extend(args['server_instance'])

    success = run_tests()
    if not success:
        sys.exit(13)
    sys.exit(0)
