
import unittest

import os

import conf


SERVER_CONFIG_FILE_TEMPLATE = '/etc/opt/fierro%s/fierroserver.conf'


class TestFierroServer(unittest.TestCase):

    def __init__(self, methodName, fierro_instance=''):
        super(TestFierroServer, self).__init__(methodName)

        self.fierro_instance = fierro_instance
        self.test_method_name = methodName
        self.server_config_file = SERVER_CONFIG_FILE_TEMPLATE % fierro_instance

    def shortDescription(self):
        if self.fierro_instance:
            return '%s (instancia %s) (%s)' % (self.test_method_name,
                                               self.fierro_instance,
                                               '.'.join(self.id().split('.')[:-1]))

    def setUp(self):
        config = {}
        execfile(self.server_config_file, config)
        self.SERVER_PORT = config['SERVER_PORT']
        self.CONF_PATH = config['CONF_PATH']

    def test_accessrules_existe(self):
        access_rules = os.path.join(self.CONF_PATH, 'accessrules.xml')
        self.assertTrue(os.path.isfile(access_rules))

    def test_se_puede_obtener_lista_de_sucursales_de_server_local(self):
        import Pyro.core

        pyro_server = Pyro.core.getProxyForURI('PYROLOC://localhost:%s/dispatcher' % self.SERVER_PORT)
        pyro_server._setTimeout(5)
        pyro_server.run("/login", "getSucursales", ())


def load_tests(loader, tests, pattern):
    suite = unittest.TestSuite()
    if 'fierroserver' not in conf.TEST_COMPONENTS:
        return suite

    test_cases = loader.getTestCaseNames(TestFierroServer)

    for instance in conf.FIERROSERVER_INSTANCES:
        for test_case in test_cases:
            suite.addTest(TestFierroServer(test_case, fierro_instance=instance))

    return suite
